# app_conf

Application Process Configuration

[![Build Status](https://travis-ci.org/axiros/app_conf.svg?branch=master)](https://travis-ci.org/axiros/app_conf)

[![Coverage Status](https://coveralls.io/repos/github/axiros/app_conf/badge.svg?branch=master)](https://coveralls.io/github/axiros/app_conf?branch=master)

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
